Flacro
======

.. image:: https://secure.travis-ci.org/thrisp/flacro.png?branch=develop

.. image:: https://pypip.in/v/Flask-Flacro/badge.png
    :target: https://pypi.python.org/pypi/Flask-Flacro/
    :alt: Latest Version

.. image:: https://pypip.in/d/Flask-Flacro/badge.png
    :target: https://pypi.python.org/pypi/Flask-Flacro/
    :alt: Downloads

.. image:: https://pypip.in/license/Flask-Flacro/badge.png
    :target: https://pypi.python.org/pypi/Flask-Flacro/
    :alt: License

Tools for working with template macros in flask/jinja2 
